==> nodus-framework-0.1.8.tgz: package/lib/program.js <==
'use strict';

const DEFAULT_SHUTDOWN_DELAY = 5000;

// ** Dependencies
const util = require('util');
const EventEmitter = require('events').EventEmitter;
const errors = require('./errors');
const logger = require('./logging').createLogger('program');

// Program Events
const events = new EventEmitter();

function shutdown(delay) {

    delay = delay || DEFAULT_SHUTDOWN_DELAY;

    logger.debug('Shutting down program...');
    events.emit('shutdown');

    setTimeout(() => {
        logger.debug('The program did not shutdown in time forcing shutdown...', {
            delay: delay * .001 + ' seconds'
        });

        process.exit();
    }, delay ).unref();
}

// Add process hooks
process.on('SIGINT', function () {
    logger.debug('**** RECEIVED SIGNAL [SIGINT] ****');
    shutdown()
});

process.on('SIGTERM', function () {
    logger.debug('**** RECEIVED SIGNAL [SIGTERM] ****');
    shutdown()
});

/**
 * Run an action on a specified interval
 * - Cancels the timer on shutdown
 * @param interval
 * @param func
 * @constructor
 */
function setTimer(interval, func) {

    if (arguments.length !== 2)
        throw errors('ARGUMENT_ERROR', 'The setInterval function requires two arguments');

    // setInterval(func, interval) -> setInterval(interval, func)
    // - Support passing interval first and last
    if (util.isFunction(arguments[0]))
        return setTimer(arguments[1], arguments[0]);

    // Set an interval timer
    const timer = setInterval(func, interval);

    // Auto-cancel timer on program.shutdown()
    events.on('shutdown', () => {
        logger.debug('Clearing interval timer...', timer);
        clearInterval(timer);
    });

    return timer;
}

// ** Exports
module.exports.on = events.on.bind(events);
module.exports.setTimer = setTimer;
module.exports.shutdown = shutdown;

==> nodus-framework-0.5.8.tgz: package/lib/program.js <==
'use strict';

const DEFAULT_SHUTDOWN_DELAY = 5000;

// ** Dependencies
const util = require('util');
const EventEmitter = require('events').EventEmitter;
const errors = require('./errors');
const logger = require('./logger').createLogger('program');

// Program Events
const events = new EventEmitter();

function shutdown(delay) {

    delay = delay || DEFAULT_SHUTDOWN_DELAY;

    logger.debug('Shutting down program...');
    events.emit('shutdown');

    setTimeout(() => {
        logger.debug('The program did not shutdown in time forcing shutdown...', {
            delay: delay * .001 + ' seconds'
        });

        process.exit();
    }, delay ).unref();
}

// Add process hooks
process.on('SIGINT', function () {
    logger.debug('**** RECEIVED SIGNAL [SIGINT] ****');
    shutdown()
});

process.on('SIGTERM', function () {
    logger.debug('**** RECEIVED SIGNAL [SIGTERM] ****');
    shutdown()
});

/**
 * Run an action on a specified interval
 * - Cancels the timer on shutdown
 * @param interval
 * @param func
 * @constructor
 */
function setTimer(interval, func) {

    if (arguments.length !== 2)
        throw errors('ARGUMENT_ERROR', 'The setInterval function requires two arguments');

    // setInterval(func, interval) -> setInterval(interval, func)
    // - Support passing interval first and last
    if (util.isFunction(arguments[0]))
        return setTimer(arguments[1], arguments[0]);

    // Set an interval timer
    const timer = setInterval(func, interval);

    // Auto-cancel timer on program.shutdown()
    events.on('shutdown', () => {
        logger.debug('Clearing interval timer...', timer);
        clearInterval(timer);
    });

    return timer;
}

// ** Exports
module.exports.on = events.on.bind(events);
module.exports.setTimer = setTimer;
module.exports.shutdown = shutdown;
